@@ -1,9 +1,12 @@
 #!/usr/bin/python3
 
 from lintian_brush.control import (
-    ensure_minimum_debhelper_version,
-    update_control,
+    ControlUpdater,
     )
+from lintian_brush.debhelper import (
+    ensure_minimum_debhelper_version,
+    )
+from lintian_brush.fixer import report_result
 from lintian_brush.rules import (
     update_rules,
     dh_invoke_drop_with,
@@ -20,12 +23,11 @@ def cb(line, target):
     return line
 
 
-def bump_debhelper(source):
-    source["Build-Depends"] = ensure_minimum_debhelper_version(
-        source.get("Build-Depends", ""), "9.20160114")
-
-
 if update_rules(cb):
-    update_control(source_package_cb=bump_debhelper)
-print("Drop use of autotools-dev debhelper.")
-print("Fixed-Lintian-Tags: debhelper-tools-from-autotools-dev-are-deprecated")
+    with ControlUpdater() as updater:
+        ensure_minimum_debhelper_version(updater.source, "9.20160114")
+
+
+report_result(
+    "Drop use of autotools-dev debhelper.",
+    fixed_lintian_tags=['debhelper-tools-from-autotools-dev-are-deprecated'])
