@@ -4,24 +4,31 @@ import os
 import re
 import subprocess
 import sys
+from typing import Optional, Tuple
 from urllib.request import urlopen, Request
 
-from lintian_brush import USER_AGENT, DEFAULT_URLLIB_TIMEOUT
-from lintian_brush.fixer import net_access_allowed
+from lintian_brush import (
+    USER_AGENT,
+    DEFAULT_URLLIB_TIMEOUT,
+    certainty_to_confidence,
+    )
+from lintian_brush.fixer import (
+    current_package_version,
+    net_access_allowed,
+    report_result,
+    package_is_native,
+    )
 from lintian_brush.watch import WatchFile, Watch
 
 
-if os.path.exists('debian/watch'):
+if os.path.exists('debian/watch') or package_is_native():
     # Nothing to do here..
     sys.exit(0)
 
+candidates = []
 
-certainty = 'possible'
-
-watch_contents = None
-site = None
-wf = WatchFile()
 if os.path.exists('setup.py'):
+    certainty = 'likely'
     try:
         lines = subprocess.check_output(
             ['python3', 'setup.py', '--name', '--version']).splitlines()
@@ -30,9 +37,9 @@ if os.path.exists('setup.py'):
         lines = subprocess.check_output(
             ['python2', 'setup.py', '--name', '--version']).splitlines()
     lines = [line for line in lines if not line.startswith(b'W: ')]
-    (project, version) = lines
-    project = project.decode()
-    version = version.decode()
+    (project_bytes, version_bytes) = lines
+    project = project_bytes.decode()
+    version = version_bytes.decode()
     current_version_filenames = None
     if net_access_allowed():
         json_url = 'https://pypi.python.org/pypi/%s/json' % project
@@ -61,19 +68,22 @@ if os.path.exists('setup.py'):
         'project': project, 'fname_regex': filename_regex})
     # TODO(jelmer): Add pgpsigurlmangle if has_sig==True
     w = Watch(url, opts=opts)
-    wf.entries.append(w)
-    site = "pypi"
+    candidates.append((w, 'pypi', certainty))
 
 
 def guess_github_watch_entry(parsed_url, upstream_version):
     from breezy.branch import Branch
     import re
     if not net_access_allowed():
-        return None
+        return None, None
     branch = Branch.open(code['Repository'])
     tags = branch.tags.get_tag_dict()
     POSSIBLE_PATTERNS = [r"v(\d\S+)", r"(\d\S+)"]
     version_pattern = None
+    # TODO(jelmer): Maybe use releases API instead?
+    # TODO(jelmer): Automatically added mangling for
+    # e.g. rc and beta
+    uversionmangle = []
     for name in sorted(tags, reverse=True):
         for pattern in POSSIBLE_PATTERNS:
             m = re.match(pattern, name)
@@ -85,57 +95,74 @@ def guess_github_watch_entry(parsed_url, upstream_version):
         if version_pattern:
             break
     else:
-        return None
+        return None, None
     (username, project) = parsed_url.path.strip('/').split('/')
+    if project.endswith('.git'):
+        project = project[:-4]
     download_url = 'https://github.com/%(user)s/%(project)s/tags' % {
         'user': username, 'project': project}
-    matching_pattern = r'.*/%s\.tar\.gz' % version_pattern
+    matching_pattern = r'.*\/%s\.tar\.gz' % version_pattern
     opts = []
     opts.append(
         r'filenamemangle=s/%(pattern)s/%(project)s-$1\.tar\.gz/' % {
             'pattern': matching_pattern,
             'project': project})
+    if uversionmangle:
+        opts.append(r'uversionmangle=' + ';'.join(uversionmangle))
     # TODO(jelmer): Check for GPG
     # opts.append(
     #    r'pgpsigurlmangle='
     #    r's/archive\/%s\.tar\.gz/releases\/download\/$1\/$1\.tar\.gz\.asc/' %
     #    version_pattern)
-    return Watch(download_url, matching_pattern, opts=opts)
+    return Watch(download_url, matching_pattern, opts=opts), 'certain'
 
 
-if not wf.entries:
+try:
+    with open('debian/upstream/metadata', 'r') as f:
+        inp = f.read()
+except FileNotFoundError:
+    pass
+else:
+    import ruamel.yaml
+    code = ruamel.yaml.round_trip_load(inp, preserve_quotes=True)
+
+    from urllib.parse import urlparse
+
     try:
-        with open('debian/upstream/metadata', 'r') as f:
-            inp = f.read()
-    except FileNotFoundError:
+        parsed_url = urlparse(code['Repository'])
+    except KeyError:
         pass
     else:
-        import ruamel.yaml
-        code = ruamel.yaml.round_trip_load(inp, preserve_quotes=True)
-
-        from urllib.parse import urlparse
-        from debian.changelog import Version
-
-        try:
-            parsed_url = urlparse(code['Repository'])
-        except KeyError:
-            pass
-        else:
-            upstream_version = Version(
-                os.environ['CURRENT_VERSION']).upstream_version
-            if parsed_url.hostname == 'github.com':
-                w = guess_github_watch_entry(parsed_url, upstream_version)
-                if w:
-                    site = 'github'
-                    wf.entries.append(w)
+        upstream_version = current_package_version().upstream_version
+        if parsed_url.hostname == 'github.com':
+            w, certainty = guess_github_watch_entry(
+                parsed_url, upstream_version)
+            if w:
+                candidates.append((w, 'github', certainty))
 
 
-if not wf.entries:
+if not candidates:
     sys.exit(0)
 
+winner: Optional[Tuple[Watch, str, str]] = None
+for candidate in candidates:
+    if winner is not None and (  # type: ignore
+            certainty_to_confidence(candidate[2]) >=   # type: ignore
+            certainty_to_confidence(winner[2])):
+        continue
+    winner = candidate
+
+if not winner:
+    sys.exit(0)
+
+wf = WatchFile()
+(entry, site, certainty) = winner
+wf.entries.append(winner[0])
+
 with open('debian/watch', 'w') as f:
     wf.dump(f)
 
-print("Add debian/watch file, using %s." % site)
-print("Certainty: %s" % certainty)
-print("Fixed-Lintian-Tags: debian-watch-file-is-missing")
+report_result(
+    "Add debian/watch file, using %s." % site,
+    certainty=certainty,
+    fixed_lintian_tags=['debian-watch-file-is-missing'])
