@@ -52,7 +52,7 @@ from debian.deb822 import Deb822
 from .reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 70)
+__version__ = (0, 71)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'confident', 'likely', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
@@ -788,10 +788,10 @@ def run_lintian_fixer(local_tree: WorkingTree,
         if specific_files:
             specific_files.append(changelog_path)
 
-    description = result.description
+    description = result.description + "\n"
+    description += "\n"
+    description += "Changes-By: lintian-brush\n"
     for tag in result.fixed_lintian_tags:
-        description += "\n"
-        description += "\n"
         description += "Fixes: lintian: %s\n" % tag
         description += (
             "See-also: https://lintian.debian.org/tags/%s.html\n" % tag)
