@@ -68,27 +68,59 @@ class ChangelogUpdater(Updater):
         return self._parsed
 
 
-def changes_by_author(changes):
-    linenos = []
-    change = []
-    author = None
+def changes_sections(
+        changes: List[str]
+        ) -> Iterator[
+            Tuple[Optional[str], List[int], List[List[Tuple[int, str]]]]
+        ]:
+    section: Tuple[
+        Optional[str], List[int],
+        List[List[Tuple[int, str]]]] = (None, [], [])
+    change: List[Tuple[int, str]] = []
     for i, line in enumerate(changes):
+        if not line and i == 0:
+            # Skip the first line
+            continue
         if not line:
+            section[1].append(i)
             continue
         m = re.fullmatch(r'  \[ (.*) \]', line)
         if m:
-            author = m.group(1)
+            if change:
+                section[2].append(change)
+                change = []
+            if section[1]:
+                yield section
+            section = (m.group(1), [i], [])
             continue
         if not line.startswith(INITIAL_INDENT):
-            change.append(line)
-            linenos.append(i)
+            change.append((i, line))
+            section[1].append(i)
         else:
             if change:
-                yield (author, linenos, change)
-            change = [line]
-            linenos = [i]
+                section[2].append(change)
+            change = [(i, line)]
+            section[1].append(i)
     if change:
-        yield (author, linenos, change)
+        section[2].append(change)
+    if section[1]:
+        yield section
+
+
+def changes_by_author(
+        changes: List[str]
+        ) -> Iterator[Tuple[Optional[str], List[int], List[str]]]:
+    """Changes by author.
+
+    Args:
+      changes: Find changes by author from a list of lines
+    Returns:
+      Iterator over items by author (maintainer, offsets, changes)
+    """
+    for (author, linenos, contents) in changes_sections(changes):
+        for change_entries in contents:
+            change_linenos, change_lines = zip(*change_entries)
+            yield (author, change_linenos, change_lines)  # type: ignore
 
 
 class TextWrapper(textwrap.TextWrapper):
@@ -208,15 +240,17 @@ def _changelog_add_entry(
         timestamp = datetime.now()
     if maintainer is None:
         maintainer = get_maintainer()
-    if cl[0].distributions == 'UNRELEASED':
+    if (cl[0].distributions == 'UNRELEASED' or (
+            cl[0].author is None and cl[0].date is None)):
         by_author = list(changes_by_author(cl[0].changes()))
         if all([author is None for (author, linenos, change) in by_author]):
-            entry_maintainer = parseaddr(cl[0].author)
-            if entry_maintainer != maintainer:
-                cl[0]._changes.insert(1, '  [ %s ]' % entry_maintainer[0])
-                if cl[0]._changes[-1]:
-                    cl[0]._changes.append('')
-                cl[0]._changes.append('  [ %s ]' % maintainer[0])
+            if cl[0].author is not None:
+                entry_maintainer = parseaddr(cl[0].author)
+                if entry_maintainer != maintainer:
+                    cl[0]._changes.insert(1, '  [ %s ]' % entry_maintainer[0])
+                    if cl[0]._changes[-1]:
+                        cl[0]._changes.append('')
+                    cl[0]._changes.append('  [ %s ]' % maintainer[0])
         else:
             if by_author[-1][0] != maintainer[0]:
                 if cl[0]._changes[-1]:
