@@ -19,6 +19,7 @@
 
 from breezy.tests import (
     TestCase,
+    TestCaseWithTransport,
     )
 
 from io import StringIO
@@ -27,6 +28,8 @@ from lintian_brush.watch import (
     parse_watch_file,
     MissingVersion,
     Watch,
+    WatchFile,
+    WatchUpdater,
     )
 
 
@@ -117,6 +120,30 @@ opts="pgpmode=mangle" https://samba.org/~jelmer blah-(\\d+).tar.gz
             [Watch('https://samba.org/~jelmer',
                    'blah-(\\d+).tar.gz', opts=['pgpmode=mangle'])])
 
+    def test_parse_continued_leading_spaces_4(self):
+        wf = parse_watch_file(StringIO("""\
+version=4
+opts=pgpmode=mangle,\\
+    foo=bar https://samba.org/~jelmer blah-(\\d+).tar.gz
+"""))
+        self.assertEqual(4, wf.version)
+        self.assertEqual(
+            wf.entries,
+            [Watch('https://samba.org/~jelmer',
+                   'blah-(\\d+).tar.gz', opts=['pgpmode=mangle', 'foo=bar'])])
+
+    def test_parse_continued_leading_spaces_3(self):
+        wf = parse_watch_file(StringIO("""\
+version=3
+opts=pgpmode=mangle,\\
+    foo=bar blah-(\\d+).tar.gz
+"""))
+        self.assertEqual(3, wf.version)
+        self.assertEqual(
+            wf.entries,
+            [Watch('foo=bar',
+                   'blah-(\\d+).tar.gz', opts=['pgpmode=mangle', ''])])
+
     def test_pattern_included(self):
         wf = parse_watch_file(StringIO("""\
 version=4
@@ -156,3 +183,24 @@ https://samba.org/~jelmer/@PACKAGE@ blah-(\\d+).tar.gz
         self.assertEqual(
             'https://samba.org/~jelmer/blah',
             wf.entries[0].format_url('blah'))
+
+
+class WatchUpdaterTests(TestCaseWithTransport):
+
+    def test_file_with_just_comments(self):
+        self.build_tree_contents([('watch', '# tests\n')])
+        with WatchUpdater('watch') as updater:
+            self.assertEqual(WatchFile([]), updater.watch_file)
+        self.assertFileEqual('# tests\n', 'watch')
+
+    def test_version_change(self):
+        self.build_tree_contents([('watch', """\
+version=3
+https://pypi.debian.net/case case-(.+)\\.tar.gz
+""")])
+        with WatchUpdater('watch') as updater:
+            updater.watch_file.version = 4
+        self.assertFileEqual("""\
+version=4
+https://pypi.debian.net/case case-(.+)\\.tar.gz
+""", 'watch')
