@@ -27,6 +27,7 @@ __all__ = [
 
 import posixpath
 import re
+from typing import Optional, Tuple
 from urllib.parse import urlparse, urlunparse
 
 
@@ -35,21 +36,23 @@ KNOWN_GITLAB_SITES = [
     'salsa.debian.org',
     'gitlab.gnome.org',
     'gitlab.freedesktop.org',
+    'gitlab.labs.nic.cz',
     ]
 
 
-def is_gitlab_site(hostname, net_access=False):
+def is_gitlab_site(hostname: str, net_access: bool = False) -> bool:
     # TODO(jelmer): Try API to see if this is a gitlab site
     return hostname in KNOWN_GITLAB_SITES
 
 
-def split_vcs_url(url):
-    m = re.finditer(r' \[([^] ]+)\]', url)
-    try:
-        m = next(m)
+def split_vcs_url(url: str) -> Tuple[str, Optional[str], Optional[str]]:
+    subpath: Optional[str]
+    branch: Optional[str]
+    m = re.search(r' \[([^] ]+)\]', url)
+    if m:
         url = url[:m.start()] + url[m.end():]
         subpath = m.group(1)
-    except StopIteration:
+    else:
         subpath = None
     try:
         (repo_url, branch) = url.split(' -b ', 1)
@@ -59,7 +62,9 @@ def split_vcs_url(url):
     return (repo_url, branch, subpath)
 
 
-def unsplit_vcs_url(repo_url, branch=None, subpath=None):
+def unsplit_vcs_url(repo_url: str,
+                    branch: Optional[str] = None,
+                    subpath: Optional[str] = None) -> str:
     url = repo_url
     if branch:
         url = '%s -b %s' % (url, branch)
@@ -68,7 +73,47 @@ def unsplit_vcs_url(repo_url, branch=None, subpath=None):
     return url
 
 
-def sanitize_url(url):
+def find_public_vcs_url(url: str) -> Optional[str]:
+    (repo_url, branch, subpath) = split_vcs_url(url)
+    parsed = urlparse(repo_url)
+    revised_url = None
+    if parsed.hostname == 'github.com':
+        if parsed.scheme in ('https', 'http', 'git'):
+            return url
+        revised_url = urlunparse(
+                ('https', 'github.com', parsed.path, None, None, None))
+    if parsed.hostname and is_gitlab_site(parsed.hostname):
+        # Not sure if gitlab even support plain http?
+        if parsed.scheme in ('https', 'http'):
+            return url
+        if parsed.scheme == 'ssh':
+            revised_url = urlunparse(
+                ('https', parsed.hostname, parsed.path, None, None, None))
+    if parsed.hostname in (
+            'code.launchpad.net', 'bazaar.launchpad.net', 'git.launchpad.net'):
+        if parsed.scheme.startswith('http') or parsed.scheme == 'lp':
+            return url
+        if parsed.scheme in ('ssh', 'bzr+ssh'):
+            revised_url = urlunparse(
+                ('https', parsed.hostname, parsed.path, None, None, None))
+
+    if revised_url:
+        return unsplit_vcs_url(revised_url, branch, subpath)
+
+    return None
+
+
+def fixup_rcp_style_git_url(url: str) -> str:
+    (repo_url, branch, subpath) = split_vcs_url(url)
+    from breezy.location import rcp_location_to_url
+    try:
+        repo_url = rcp_location_to_url(repo_url)
+    except ValueError:
+        return url
+    return unsplit_vcs_url(repo_url, branch, subpath)
+
+
+def sanitize_url(url: str) -> str:
     url = url.strip()
     if url.startswith('git+http:') or url.startswith('git+https:'):
         url = url[4:]
@@ -77,12 +122,14 @@ def sanitize_url(url):
     if url.startswith('bzr+lp:') or url.startswith('bzr+http'):
         url = url.split('+', 1)[1]
     url = fixup_broken_git_url(url)
+    url = fixup_rcp_style_git_url(url)
+    url = find_public_vcs_url(url) or url
     url = canonical_vcs_git_url(url)
     url = find_secure_vcs_url(url, net_access=False) or url
     return url
 
 
-def plausible_url(url):
+def plausible_url(url: str) -> bool:
     return ':' in url
 
 
@@ -167,8 +214,12 @@ def fix_git_gnome_org_url(parsed, branch):
 
 def fix_freedesktop_org_url(parsed, branch):
     if parsed.netloc == 'anongit.freedesktop.org':
+        path = parsed.path
+        if path.startswith('/git/'):
+            path = path[len('/git'):]
         parsed = parsed._replace(
-            netloc='gitlab.freedesktop.org', scheme='https')
+            netloc='gitlab.freedesktop.org', scheme='https',
+            path=path)
         return parsed, branch
     return None, None
 
@@ -197,7 +248,7 @@ def fixup_broken_git_url(url):
     return url
 
 
-def browse_url_from_repo_url(url):
+def browse_url_from_repo_url(url: str) -> Optional[str]:
     parsed_url = urlparse(url)
     if parsed_url.netloc == 'github.com':
         path = '/'.join(parsed_url.path.split('/')[:3])
@@ -253,7 +304,7 @@ def determine_gitlab_browser_url(url):
     return 'https://%s%s' % (parsed_url.hostname, path)
 
 
-def determine_browser_url(vcs_type, vcs_url):
+def determine_browser_url(vcs_type, vcs_url: str) -> Optional[str]:
     repo_url, branch, subpath = split_vcs_url(vcs_url)
     parsed = urlparse(repo_url.rstrip('/'))
     if is_gitlab_site(parsed.netloc):
@@ -332,7 +383,7 @@ canonicalize_vcs_fns = {
 }
 
 
-def canonicalize_vcs_url(vcs_type, url):
+def canonicalize_vcs_url(vcs_type: str, url: str) -> str:
     try:
         return canonicalize_vcs_fns[vcs_type](url)
     except KeyError:
@@ -383,7 +434,7 @@ def find_secure_vcs_url(url, net_access=True):
     if net_access:
         secure_repo_url = parsed_repo_url._replace(scheme='https')
         insecure_branch = try_open_branch(repo_url, branch)
-        secure_branch = try_open_branch(urlunparse(parsed_repo_url), branch)
+        secure_branch = try_open_branch(urlunparse(secure_repo_url), branch)
         if secure_branch:
             if (not insecure_branch or
                     secure_branch.last_revision() ==
